@@ -1,21 +1,12 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  This is the class that shows the channel nick list
-  begin:     Fre Jun 7 2002
-  copyright: (C) 2002 by Dario Abatianni
-  email:     eisfuchs@tigress.com
+    SPDX-FileCopyrightText: 2002 Dario Abatianni <eisfuchs@tigress.com>
 */
 
 #include "nicklistview.h"
 #include "nick.h"
 #include "application.h"
-#include "images.h"
 #include "irccontextmenus.h"
 
 #include <QHeaderView>
@@ -29,8 +20,10 @@
 
 class NickItemDelegate : public QStyledItemDelegate
 {
+    Q_OBJECT
+
     public:
-        NickItemDelegate(QObject *parent = 0);
+        NickItemDelegate(QObject *parent = nullptr);
 
         QSize sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const override;
 };
@@ -52,7 +45,7 @@ int NickListView::s_minimumRowHeight = 0;
 NickListView::NickListView(QWidget* parent, Channel *chan) : QTreeWidget(parent)
 {
     setWhatsThis();
-    channel=chan;
+    m_channel = chan;
 
     // Enable Drag & Drop
     viewport()->setAcceptDrops(true);
@@ -102,7 +95,7 @@ bool NickListView::event(QEvent *event)
 {
     if(( event->type() == QEvent::ToolTip ) )
     {
-        QHelpEvent* helpEvent = static_cast<QHelpEvent*>( event );
+        auto* helpEvent = static_cast<QHelpEvent*>(event);
 
         QTreeWidgetItem *item = itemAt(viewport()->mapFromParent(helpEvent->pos()));
         if( item )
@@ -203,7 +196,7 @@ void NickListView::setSortingEnabled(bool enable)
     // if sorting is enabled.
     if (enable && header()) {
         disconnect(header(), SIGNAL(sortIndicatorChanged(int,Qt::SortOrder)),
-                this, 0);
+                this, nullptr);
     }
 }
 
@@ -261,10 +254,9 @@ int NickListView::findLowerBound(const QTreeWidgetItem& item) const
 
 void NickListView::contextMenuEvent(QContextMenuEvent* ev)
 {
-    if (selectedItems().count())
-    {
+    if (!selectedItems().isEmpty()) {
         IrcContextMenus::nickMenu(ev->globalPos(), IrcContextMenus::ShowChannelActions,
-            channel->getServer(), channel->getSelectedNickList(), channel->getName());
+            m_channel->getServer(), m_channel->getSelectedNickList(), m_channel->getName());
     }
 }
 
@@ -286,7 +278,7 @@ bool NickListView::canDecodeMime(QDropEvent const *event) const {
 
             if (first.scheme() == QLatin1String("irc") ||
                 first.scheme() == QLatin1String("ircs") ||
-                channel->getNickList().containsNick(first.url()))
+                m_channel->getNickList().containsNick(first.url()))
                 {
                     return false;
                 }
@@ -322,15 +314,15 @@ void NickListView::dragMoveEvent(QDragMoveEvent *event)
 
 bool NickListView::dropMimeData(QTreeWidgetItem *parent, int index, const QMimeData *data, Qt::DropAction action)
 {
-    Q_UNUSED(index);
-    Q_UNUSED(action);
+    Q_UNUSED(index)
+    Q_UNUSED(action)
     Nick* nick = dynamic_cast<Nick*>(parent);
     if (nick) {
         const QList<QUrl> uris = KUrlMimeData::urlsFromMimeData(data);
-        channel->getServer()->sendURIs(uris, nick->getChannelNick()->getNickname());
+        m_channel->getServer()->sendURIs(uris, nick->getChannelNick()->getNickname());
         return true;
     }
     return false;
 }
 
-
+#include "nicklistview.moc"
